import * as React from "react";
import {observer} from "mobx-react-lite";
import {ButtonGroup, Table, TableBody, TableCell, TableRow} from "@material-ui/core";
import {ComponentPermissionRow} from "./ComponentPermissionRow"
import {useReadonlyContext} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import TableHead from "@material-ui/core/TableHead";
import {TabPanel, TabPanelProps} from "./TabPanel"
import {GrantedButton} from "./GrantedButton";
import {DeniedButton} from "./DeniedButton";
import {RolePermissionModel} from "../../stores/RolePermissionStore";
import {ComponentPermissionGroup} from "../../models/ComponentPermissionGroup";

type ComponentPermissionTabProps = {
    components: Array<ComponentPermissionGroup>
} & TabPanelProps

export const ComponentPermissionTab: React.FunctionComponent<ComponentPermissionTabProps> = observer((props) => {
    const {components, value, index} = props;
    const readOnly = useReadonlyContext();

    const setAllForApp = function (granted: boolean) {
        components.forEach(component => {
            component.actions.forEach((action: { rolePermission: RolePermissionModel }) => {
                action.rolePermission.viewModel.permitted = granted;
            });
        });
    };

    return (
        <TabPanel value={value} index={index}>
            {!readOnly && <ButtonGroup color="primary" aria-label="outlined primary button group">
                <GrantedButton
                    onClick={() => setAllForApp(true)}
                >
                    {t`Grant all for App`}
                </GrantedButton>
                <DeniedButton
                    onClick={() => setAllForApp(false)}
                >
                    {t`Revoke all for App`}
                </DeniedButton>
            </ButtonGroup>}
            <Table aria-label="simple table">
                <TableHead>
                    <TableRow>
                        <TableCell>{t`Item`}</TableCell>
                        <TableCell align="left">{t`Permissions`}</TableCell>
                        {!readOnly && <TableCell align="right">{t`Quick Actions`}</TableCell>}
                    </TableRow>
                </TableHead>
                <TableBody>
                    {
                        components.sort((a, b) => a.compare(b)).map(component =>
                            <ComponentPermissionRow key={component.target.target_id} component={component}/>
                        )
                    }
                </TableBody>
            </Table>
        </TabPanel>
    );
});
