import * as React from 'react';
import {observer} from "mobx-react-lite";
import {FormProps, ModelForm, ModelInput, ModelSelect, PaddedPaper} from "@rx-suite/ui";
import {RoleStore} from "../../stores/RoleStore";
import {Model} from "@rx-suite/data";
import {Container, Grid, LinearProgress} from "@material-ui/core";
import {UserModel} from "../../stores/UserStore";
import {UserFormButtons} from "../../components/users/UserFormButtons";
import {ExternalConnectionsPanel} from "../../components/oauths/ExternalConnectionsPanel";

export type UserFormProps = { profileMode?: boolean } & FormProps
export const UserForm: React.FunctionComponent<UserFormProps> = observer(({model, readOnly, profileMode}) => {
    const Form = <>
        <Grid item xs={12}>
            <PaddedPaper>
                <ModelForm model={model}
                           readOnly={readOnly}
                           postFormActions={<UserFormButtons user={model as UserModel}/>}
                           suppressImportExport={profileMode}
                           suppressMakeCopy={profileMode}
                           suppressList={profileMode}
                           suppressWrapper>
                    <ModelInput name={"name"}/>
                    <ModelInput name={"email"}/>
                    <ModelSelect name={"table_size"} options={
                        [
                            {label: "5", value: 5},
                            {label: "10", value: 10},
                            {label: "20", value: 20},
                            {label: "25", value: 25},
                            {label: "50", value: 50},
                            {label: "100", value: 100}
                        ]
                    }
                    />
                    {RoleStore.getAll() ? <ModelSelect name={"role_id"} options={
                            Object.values(RoleStore.getAll()).filter((role: Model) => !role.isNew).map((role: Model) => ({
                                label: role.name as string, value: role.getId()
                            }))}/>
                        : <LinearProgress color={'secondary'}/>
                    }
                </ModelForm>
            </PaddedPaper>
        </Grid>
        <Grid item xs={12}>
            <ExternalConnectionsPanel user={model as UserModel} readOnly={readOnly}/>
        </Grid>
    </>;
    if (profileMode) {
        return Form;
    } else {
        return (
            <Container maxWidth={"md"}>
                <Grid container spacing={2}>
                    {Form}
                </Grid>
            </Container>
        );
    }
});
