# == Schema Information
#
# Table name: roles
#
#  id         :bigint           not null, primary key
#  name       :string
#  created_at :datetime         not null
#  updated_at :datetime         not null
#
class Role < ApplicationRecord
  has_many :users
  has_many :role_permissions, dependent: :destroy
  has_many :component_permissions, through: :role_permissions

  accepts_nested_attributes_for :role_permissions

  validates :name, presence: true

  after_save do
    InvalidateUserCachesJob.perform_later
  end

  class << self
    def revoke_from_all(component_permission)
      Role.eager_load(:role_permissions).all.each do |role|
        role.revoke(component_permission)
      end
    end
  end

  def grant(component_permission)
    role_permissions.find_or_create_by(component_permission_id: component_permission.id).tap do |rp|
      rp.permitted = true
    end.save
  end

  def revoke(component_permission)
    role_permissions.find_or_create_by(component_permission_id: component_permission.id).tap do |rp|
      rp.permitted = false
    end.save
  end

  def flat_permissions_for_frontend
    role_permissions.eager_load(component_permission: :component).map(&:flat).map do |p|
      {
        permitted: p["permitted"],
        action_id: p["action_id"],
        target_id: p["target_id"],
        component: p["component"]
      }
    end
  end

  alias_method :permissions, :flat_permissions_for_frontend
end
